tiled.structures.xarray.VariableStructure
=========================================

.. currentmodule:: tiled.structures.xarray

.. autoclass:: VariableStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~VariableStructure.__init__
      ~VariableStructure.from_json
   
   

   
   
   